/******************************************************************************/
/*
 * eRIC Example Watch Dog Timer(WDT) V1.1
 * Low Power Radio Solutions
 * March 2016
 * Built with CCS V6.1.2.00015
 * This example will explain Watch Dog Timer technique. Radio is set at 434MHz with 12dm power. Watch Dog timer(WDT) is set with 32k clock
 * source and 32768 interval which would trigger WDT interrupt at every 1 sec.Pin19 set as output and is toggled everytime WDT is triggered.
 * When WDT is trigered 5th time, a message 'WDT EXAMPLE' is sent over air. And when WDT triggers 10 times, a PUC(reset) is generated.
 * At any time, if Pin18 is held high WDT interrupt count is reset to 0.
 *
 */

/******************************************************************************/
//Version V1.1
#include<cc430f5137.h>
#include "eRIC.h"

volatile char i;
volatile const char Data[] = {'W','D','T',' ','E','X','A','M','P','L','E'};

int main(void)
{
	eRIC_WDT_Stop();                   //Stop watch dog timer, just in case
	eRIC_GlobalInterruptDisable();     //Global interrupts disabled
	eROS_Initialise(434000000);        //Initialise eROS with 434Mhz
	eRIC_Power = 12;                   //Set transmit power as 12dbm
	eRIC_RadioUpdate();                //Update radio

	eRIC_Stringcopy(eRIC_RadioTx_Buffer,Data,11);  //Copy Data in to Tx buffer to transmit over air

	Pin19_SetAsOutput();               //Set Pin19 as output
	Pin18_SetAsInput();                //Set Pin18 as Input
	eRIC_WDT_Setup(eRICWDT_Cs_32k+eRICWDT_Interval_32768);    //Setup WDT with 32k clock and 32768 interval which would set flag at 1 sec interval
	i =0;
	eRIC_GlobalInterruptEnable();      //Enable global interrupts
	eRIC_WDT_InterruptEnable();        //Enable WDT interrupt
	eRIC_WDT_Start();                  //Start WDT
	while(1)//Loop continously
	{
		if(Pin18_Read())               //Reset i  to 0 if pin18 is high
		{
			while(Pin18_Read())
				i =0;
		}
		if(i==5)                      //Transmit "WDT Example" data when i =5
		{
			eRIC_RadioTx_BuffCount = 11;
			eRIC_RfSenddata();
			while(i==5); //send only once and wait here until i>5
		}
	}
}//end of main


#pragma vector= WDT_VECTOR
__interrupt void WDT_ISR(void)
{
	eRIC_WDT_Stop();                   //Stop WDT
	i++;
	if(i==10)
	{
		eRIC_PowerOnReset();           //Reset eRIC when i =10
	}
	Pin19_Toggle();                   //Toggle Pin19
	eRIC_WDT_Reset();                 //Reset WDT
	eRIC_WDT_Start();                 //Start WDT
}

void eRIC_RfDataReceivedInterrupt()   //Add code here to deal with  available received data..This is triggered when interrupt is enabled and a packet is received
{
}


